=======
History
=======

0.0.8 (2024-06-27)
------------------

* feat: Add support for skipping download and verification of buildinfo file it is already exists

0.0.7 (2024-06-26)
------------------

* feat: Add support for .buildinfo from a PPA

0.0.6 (2024-06-05)
------------------

* feat: optionally do not download buildinfo file. `--no-download` flag checks for existence only

0.0.5 (2024-02-19)
------------------

* fix: ensure correct architecture build artifacts are downloaded

0.0.4 (2024-02-01)
------------------

* Fix for querying by source package even if the package was a copy from a previous Ubuntu release.

0.0.3 (2024-01-31)
------------------

* Allow for querying by source package.

0.0.2 (2024-01-24)
------------------

* No longer iterate over pocket and publication status for much quicker query times.

0.0.1 (2024-01-24)
------------------

* First release on PyPI.
